IntoF64

Trait IntoF64 

pub trait IntoF64 {
    // Required method
    fn into_f64(self) -> f64;
}
An object which can be converted into a f64 representation.

This trait provides a mechanism for existing types, which have a natural representation as a 64-bit floating-point number, to be transparently passed in when recording a histogram.

Required Methods

fn into_f64(self) -> f64

Converts this object to its f64 representation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoF64 for Duration

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for f32

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for f64

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for i8

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for i16

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for i32

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for u8

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for u16

Source

fn into_f64(self) -> f64

Source

impl IntoF64 for u32

Source

fn into_f64(self) -> f64

Implementors